"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.useHeaderDimensions = void 0;
const react_native_1 = require("react-native");
const react_native_safe_area_context_1 = require("react-native-safe-area-context");
const font_scale_context_1 = require("../__contexts__/font-scale-context");
/**
 * useHeaderDimensions hook
 *
 * This hook is used to provide the 'constant' values for the Header height in the collapsed
 * and expanded states. These values can change when the device rotates based on the safe areas
 * and presence or absence of a status bar.
 *
 * This hook listens for device rotation changes and makes sure the the correct constant values
 * are being returned
 *
 * @returns { REGULAR_HEIGHT, EXTENDED_HEIGHT, LANDSCAPE, getScaledHeight }
 */
const useHeaderDimensions = () => {
    const { width: deviceWidth, height: deviceHeight } = (0, react_native_1.useWindowDimensions)();
    const fontScale = (0, font_scale_context_1.useFontScale)();
    const insets = (0, react_native_safe_area_context_1.useSafeAreaInsets)();
    const isLandscape = deviceWidth > deviceHeight;
    const heightWithStatusBar = (height) => height * fontScale + insets.top;
    const heightWithoutStatusBar = (height) => height * fontScale;
    const LANDSCAPE_HEIGHT = {
        EXTENDED: heightWithoutStatusBar(200),
        REGULAR: heightWithoutStatusBar(56),
    };
    const PORTRAIT_HEIGHT = {
        EXTENDED: heightWithStatusBar(200),
        REGULAR: heightWithStatusBar(56),
    };
    const REGULAR_HEIGHT = isLandscape ? LANDSCAPE_HEIGHT.REGULAR : PORTRAIT_HEIGHT.REGULAR;
    const EXTENDED_HEIGHT = isLandscape ? LANDSCAPE_HEIGHT.EXTENDED : PORTRAIT_HEIGHT.EXTENDED;
    const getScaledHeight = isLandscape ? heightWithoutStatusBar : heightWithStatusBar;
    return {
        REGULAR_HEIGHT,
        EXTENDED_HEIGHT,
        LANDSCAPE: isLandscape,
        getScaledHeight,
    };
};
exports.useHeaderDimensions = useHeaderDimensions;
