"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.Overline = exports.Caption = exports.Button = exports.Subtitle2 = exports.Subtitle1 = exports.Label = exports.Body2 = exports.Body1 = exports.H6 = exports.H5 = exports.H4 = exports.H3 = exports.H2 = exports.H1 = void 0;
const react_1 = __importDefault(require("react"));
const react_native_1 = require("react-native");
const react_native_paper_1 = require("react-native-paper");
const font_scale_context_1 = require("../__contexts__/font-scale-context");
/**
 * createTypography function
 * createTypography is a component-generator function. It returns a Text component styled based on
 * the getStyle function that is passed as an argument.
 *
 * @param getStyle a function that takes in a theme and returns a text style object
 * @returns a theme-wrapped text component that utilizes that styles and theme that are provided
 */
const createTypography = (getStyle) => ({ font, fontSize, color, style, styles = {}, ...props }) => {
    const theme = (0, react_native_paper_1.useTheme)(props.theme);
    const { maxScale, disableScaling } = (0, font_scale_context_1.useFontScaleSettings)();
    let customStyle = {};
    if (fontSize) {
        customStyle.fontSize = fontSize;
    }
    if (font) {
        customStyle = {
            ...customStyle,
            ...theme.fonts[font],
        };
    }
    let appliedColor = theme.colors.text;
    if (color) {
        if (['primary', 'accent', 'error', 'text', 'notification'].includes(color || ''))
            appliedColor = theme.colors[color];
        else
            appliedColor = color;
    }
    return (react_1.default.createElement(react_native_1.Text, { ...props, style: [
            { color: appliedColor },
            { writingDirection: react_native_1.I18nManager.isRTL ? 'rtl' : 'ltr' },
            react_native_1.Platform.OS === 'android' ? { textAlign: 'left' } : {},
            getStyle(theme),
            customStyle,
            styles.root,
            style,
        ], allowFontScaling: !disableScaling, maxFontSizeMultiplier: maxScale }));
};
/**
 * [H1](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An H1 heading
 */
exports.H1 = createTypography((theme) => ({
    ...theme.fonts.light,
    fontSize: 96,
    letterSpacing: 0,
}));
/**
 * [H2](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An H2 heading
 */
exports.H2 = createTypography((theme) => ({
    ...theme.fonts.light,
    fontSize: 60,
    letterSpacing: 0,
}));
/**
 * [H3](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An H3 heading
 */
exports.H3 = createTypography((theme) => ({
    ...theme.fonts.regular,
    fontSize: 48,
    letterSpacing: 0,
}));
/**
 * [H4](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An H4 heading
 */
exports.H4 = createTypography((theme) => ({
    ...theme.fonts.regular,
    fontSize: 34,
    letterSpacing: 0,
}));
/**
 * [H5](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An H5 heading
 */
exports.H5 = createTypography((theme) => ({
    ...theme.fonts.regular,
    fontSize: 24,
    letterSpacing: 0,
}));
/**
 * [H6](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An H6 heading (used commonly for titles)
 */
exports.H6 = createTypography((theme) => ({
    ...theme.fonts.medium,
    fontSize: 20,
    letterSpacing: 0,
}));
/**
 * [Body1](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * A text component used for most body copy
 */
exports.Body1 = createTypography((theme) => ({
    ...theme.fonts.regular,
    fontSize: 16,
    letterSpacing: 0,
}));
/**
 * [Body2](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * A text component used for alternative body copy
 */
exports.Body2 = createTypography((theme) => ({
    ...theme.fonts.regular,
    fontSize: 14,
    letterSpacing: 0,
}));
/**
 * [Label](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * A secret, undocumented text component used for some labels in very specific places.
 *
 * Not intended for general use.
 */
exports.Label = createTypography((theme) => ({
    ...theme.fonts.regular,
    fontSize: 16,
    letterSpacing: 0,
}));
/**
 * [Subtitle1](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * A subtitle component
 */
exports.Subtitle1 = createTypography((theme) => ({
    ...theme.fonts.medium,
    fontSize: 16,
    letterSpacing: 0,
}));
/**
 * [Subtitle2](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An alternative subtitle component
 */
exports.Subtitle2 = createTypography((theme) => ({
    ...theme.fonts.medium,
    fontSize: 14,
    letterSpacing: 0,
}));
/**
 * [Button](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * A text component used for button labels
 */
exports.Button = createTypography((theme) => ({
    ...theme.fonts.regular,
    fontSize: 14,
    letterSpacing: 0,
}));
/**
 * [Caption](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * A text component used for image captions
 */
exports.Caption = createTypography((theme) => ({
    ...theme.fonts.regular,
    fontSize: 12,
    letterSpacing: 0,
}));
/**
 * [Overline](https://brightlayer-ui-components.github.io/react-native/?path=/info/components-documentation--typography) component
 *
 * An all-caps text component used for specific labeling situations.
 */
exports.Overline = createTypography((theme) => ({
    ...theme.fonts.regular,
    fontSize: 12,
    letterSpacing: 2,
    textTransform: 'uppercase',
}));
